package mschmidt.komo.datatools;
/*
 * Instances of this wizard object clase control the database vacuum operation.
 */

import mschmidt.komo.Application;
import mschmidt.komo.ApplicationImages;
import mschmidt.komo.KomoPlugin;

import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.wizard.Wizard;

public class VacuumWizard extends Wizard {

	// instantiate the data model
	VacuumData data = new VacuumData();

	/*
	 * Constructor to create the wizard and initializes variables.
	 */
	public VacuumWizard() {
		setWindowTitle("Database Maintenance");
		setDefaultPageImageDescriptor(KomoPlugin
				.getImageDescriptor(ApplicationImages.DB_VACUUM32_ICON));

		// Create dialog settings if they don't exist, then set them.
		IDialogSettings dlgSettings = KomoPlugin.getDefault()
				.getDialogSettings().getSection("VacuumSection");
		if (dlgSettings == null) {
			dlgSettings = KomoPlugin.getDefault().getDialogSettings()
					.addNewSection("VacuumSection");
			dlgSettings.put(WizardConstants.VACUUM_ANALYZE, true);
			dlgSettings.put(WizardConstants.VACUUM_FREEZE, false);
			dlgSettings.put(WizardConstants.VACUUM_FULL, true);
			dlgSettings.put(WizardConstants.VACUUM_VERBOSE, true);
		}
		setDialogSettings(dlgSettings);
		data.doAnalyze = getDialogSettings().getBoolean(
				WizardConstants.VACUUM_ANALYZE);
		data.doFreeze = getDialogSettings().getBoolean(
				WizardConstants.VACUUM_FREEZE);
		data.doFull = getDialogSettings().getBoolean(
				WizardConstants.VACUUM_FULL);
		data.doVerbose = getDialogSettings().getBoolean(
				WizardConstants.VACUUM_VERBOSE);

	}

	/*
	 * (non-Javadoc) Add page to the wizard.
	 * 
	 * @see org.eclipse.jface.wizard.IWizard#addPages()
	 */
	@Override
	public final void addPages() {
		VacuumWizardPage page = new VacuumWizardPage();
		addPage(page);
	}

	/*
	 * (non-Javadoc) Processing that occurs when the Finish button is pressed.
	 * 
	 * @see org.eclipse.jface.wizard.IWizard#performFinish()
	 */
	@Override
	public final boolean performFinish() {

		// Save dialog settings
		if (getDialogSettings() != null) {
			getDialogSettings().put(WizardConstants.VACUUM_ANALYZE,
					data.doAnalyze);
			getDialogSettings().put(WizardConstants.VACUUM_FREEZE,
					data.doFreeze);
			getDialogSettings().put(WizardConstants.VACUUM_FULL, data.doFull);
			getDialogSettings()
					.put(WizardConstants.VACUUM_VERBOSE, data.doFull);
		}

		// Check for password and then run vacuum job
		if (Application.dbPassword.checkPassword()) {
			String stmt = "VACUUM";
			if (data.doFull) {
				stmt = stmt + " FULL";
			}
			if (data.doFreeze) {
				stmt = stmt + " FREEZE";
			}
			if (data.doVerbose) {
				stmt = stmt + " VERBOSE";
			}
			if (data.doAnalyze) {
				stmt = stmt + " ANALYZE";
			}
			Job vacuumJob = new UtilitySqlJob("Vacuum",
					ApplicationImages.DB_VACUUM_ICON, stmt);
			vacuumJob.schedule();
		}

		return true;
	}

}
